@@ -27,12 +27,14 @@ def wrap_func_shape_as_first_arg(func, *args, **kwargs):
         shape = (shape,)
 
     chunks = kwargs.pop('chunks', None)
-    chunks = normalize_chunks(chunks, shape)
-    name = kwargs.pop('name', None)
 
     dtype = kwargs.pop('dtype', None)
     if dtype is None:
         dtype = func(shape, *args, **kwargs).dtype
+    dtype = np.dtype(dtype)
+
+    chunks = normalize_chunks(chunks, shape, dtype=dtype)
+    name = kwargs.pop('name', None)
 
     name = name or 'wrapped-' + tokenize(func, shape, chunks, dtype, args, kwargs)
 
