@@ -6,7 +6,7 @@ from .groupby import Aggregation
 from .io import (from_array, from_pandas, from_bcolz,
                  from_dask_array, read_hdf, read_sql_table,
                  from_delayed, read_csv, to_csv, read_table,
-                 demo, to_hdf, to_records, to_bag)
+                 demo, to_hdf, to_records, to_bag, read_json, to_json)
 from .optimize import optimize
 from .multi import merge, concat
 from . import rolling
