@@ -313,11 +313,9 @@ def test_to_hdf_exceptions():
                 a.to_hdf(hdf, '/data_*_*')
 
 
-@pytest.mark.parametrize('get', [dask.get,
-                                 dask.threaded.get,
-                                 dask.multiprocessing.get])
+@pytest.mark.parametrize('scheduler', ['sync', 'threads', 'processes'])
 @pytest.mark.parametrize('npartitions', [1, 4, 10])
-def test_to_hdf_schedulers(get, npartitions):
+def test_to_hdf_schedulers(scheduler, npartitions):
     pytest.importorskip('tables')
     df = pd.DataFrame({'x': ['a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p'],
                        'y': [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16]},
@@ -326,20 +324,20 @@ def test_to_hdf_schedulers(get, npartitions):
 
     # test single file single node
     with tmpfile('h5') as fn:
-        a.to_hdf(fn, '/data', get=get)
+        a.to_hdf(fn, '/data', scheduler=scheduler)
         out = pd.read_hdf(fn, '/data')
         assert_eq(df, out)
 
     # test multiple files single node
     with tmpdir() as dn:
         fn = os.path.join(dn, 'data_*.h5')
-        a.to_hdf(fn, '/data', get=get)
+        a.to_hdf(fn, '/data', scheduler=scheduler)
         out = dd.read_hdf(fn, '/data')
         assert_eq(df, out)
 
     # test single file multiple nodes
     with tmpfile('h5') as fn:
-        a.to_hdf(fn, '/data*', get=get)
+        a.to_hdf(fn, '/data*', scheduler=scheduler)
         out = dd.read_hdf(fn, '/data*')
         assert_eq(df, out)
 
@@ -484,7 +482,7 @@ def test_hdf_globbing():
         df.to_hdf(os.path.join(tdir, 'two.h5'), '/bar/data', format='table')
         df.to_hdf(os.path.join(tdir, 'two.h5'), '/foo/data', format='table')
 
-        with dask.set_options(get=dask.get):
+        with dask.config.set(scheduler='sync'):
             res = dd.read_hdf(os.path.join(tdir, 'one.h5'), '/*/data',
                               chunksize=2)
             assert res.npartitions == 2
@@ -518,7 +516,7 @@ def test_hdf_file_list():
         df.iloc[:2].to_hdf(os.path.join(tdir, 'one.h5'), 'dataframe', format='table')
         df.iloc[2:].to_hdf(os.path.join(tdir, 'two.h5'), 'dataframe', format='table')
 
-        with dask.set_options(get=dask.get):
+        with dask.config.set(scheduler='sync'):
             input_files = [os.path.join(tdir, 'one.h5'), os.path.join(tdir, 'two.h5')]
             res = dd.read_hdf(input_files, 'dataframe')
             tm.assert_frame_equal(res.compute(), df)
